CREATE OR REPLACE PACKAGE plpdf_toolkit is
/**
 <config>
  <pck-name>PL/PDF Toolkit</pck-name>
  <pck-title>User's Guide</pck-title>
  <pck-version>v2.0.8</pck-version>
  <header-prc>plpdf_doc_xml.plpdf_header</header-prc>
  <header-size>15</header-size>
  <footer-prc>plpdf_doc_xml.plpdf_footer</footer-prc>
  <footer-size>10</footer-size>
 </config>
*/

/**
<h1>Introdution</h1>
<br/>
<p>
 PL/PDF Toolkit is a java library with PL/SQL interface for manipulating existing PDF documents.
</p>
<newpage/>
*/

/**
<h1>Certification</h1>
<h2>GetCertKey</h2>
<type>Function</type>
<desc>
  Generates preliminary certification key.
  This function should be run once when the PL/PDF package is installed. The function generates a string
  that should be sent to <a>mailto:info@plpdf.com</a>. Our representatives will send a certificate key back that should
  be used as the return value in the <i>pl_pdf_cert.SetCertKey</i> function.
</desc>
<params>-</params>
<return>
 <return-def>varchar2</return-def>
 <return-desc>Preliminary certificate key</return-desc>
</return>
<newpage/>
*/
function GetCertKey
  return varchar2;

/**
<h1>Types And Constants</h1>
<h2>t14font</h2>
<type>Subtype, VARHCAR2(30 CHAR)</type>
<desc>
 Standard Type 1 Fonts<br/>
 The PostScript names of 14 Type 1 fonts, known as the standard fonts.
 These fonts, or their font metrics and suitable substitution fonts, are required to be available to the viewer application.
</desc>
<br/>
*/
subtype t_14font is varchar2(30 char);

/**
<h2>t_color</h2>
<type>Record</type>
<desc>
Represents the RGB color triplet.
</desc>
<fields>
 <field>
  <field-def>r number</field-def>
  <field-desc>Value of the red component</field-desc>
 </field>
 <field>
  <field-def>g number</field-def>
  <field-desc>Value of the green component</field-desc>
 </field>
 <field>
  <field-def>b number</field-def>
  <field-desc>Value of the blue component</field-desc>
 </field>
</fields>
*/
type t_color is record (
  r number,
  g number,
  b number
  );
/**
<br/>
<h2>times-roman</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Roman</constant-desc>
</constant>

<h2>times_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Bold</constant-desc>
</constant>

<h2>times_italic</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Italic</constant-desc>
</constant>

<h2>times_bold_italic</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-BoldItalic</constant-desc>
</constant>

<h2>helvetica</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica</constant-desc>
</constant>

<h2>helvetica_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-Bold</constant-desc>
</constant>

<h2>helvetica_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-Oblique</constant-desc>
</constant>

<h2>helvetica_bold_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-BoldOblique</constant-desc>
</constant>

<h2>courier</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier</constant-desc>
</constant>

<h2>courier_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-Bold</constant-desc>
</constant>

<h2>courier_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-Oblique</constant-desc>
</constant>

<h2>courier_bold_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-BoldOblique</constant-desc>
</constant>

<h2>symbol</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Symbol</constant-desc>
</constant>

<h2>zapf_dingbats</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>ZapfDingbats</constant-desc>
</constant>
<newpage/>
*/
  times_roman constant t_14font := 'Times-Roman';
  times_bold constant t_14font := 'Times-Bold';
  times_italic constant t_14font := 'Times-Italic';
  times_bold_italic constant t_14font := 'Times-BoldItalic';
  helvetica constant t_14font := 'Helvetica';
  helvetica_bold constant t_14font := 'Helvetica-Bold';
  helvetica_oblique constant t_14font := 'Helvetica-Oblique';
  helvetica_bold_oblique constant t_14font := 'Helvetica-BoldOblique';
  courier constant t_14font := 'Courier';
  courier_bold constant t_14font := 'Courier-Bold';
  courier_oblique constant t_14font := 'Courier-Oblique';
  courier_bold_oblique constant t_14font := 'Courier-BoldOblique';
  symbol constant t_14font := 'Symbol';
  zapf_dingbats constant t_14font := 'ZapfDingbats';

/**
<br/>
<h2>Metadata</h2>
<type>Record</type>
<desc>
  A PDF document may include general information such as the document?s title,
  author, and creation and modification dates. Such global information about the
  document itself (as opposed to its content or structure) is called metadata, and is
  intended to assist in cataloguing and searching for documents in external databases.
</desc>
<fields>
 <field>
  <field-def>Title</field-def>
  <field-desc>The document?s title</field-desc>
 </field>
 <field>
  <field-def>Author</field-def>
  <field-desc>The name of the person who created the document</field-desc>
 </field>
 <field>
  <field-def>Subject</field-def>
  <field-desc>The subject of the document</field-desc>
 </field>
 <field>
  <field-def>Creator</field-def>
  <field-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Adobe FrameMaker?) that created the
   original document from which it was converted.
  </field-desc>
 </field>
 <field>
  <field-def>Keywords</field-def>
  <field-desc>Keywords associated with the document</field-desc>
 </field>
 <field>
  <field-def>Producer</field-def>
  <field-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Acrobat Distiller) that converted it to PDF.
  </field-desc>
 </field>
 <field>
  <field-def>CreationDate</field-def>
  <field-desc>The date and time the document was created, in human-readable form</field-desc>
 </field>
 <field>
  <field-def>ModDate</field-def>
  <field-desc>The date and time the document was most recently modified, in human-readable form</field-desc>
 </field>
</fields>
*/
type t_metadata is record (
  Title varchar2(2000 char),
  Author varchar2(2000 char),
  Subject varchar2(2000 char),
  Creator varchar2(2000 char),
  Keywords varchar2(2000 char),
  Producer varchar2(2000 char),
  CreationDate date,
  ModDate date
  );

/**
<br/>
<h2>Merge input</h2>
<type>Record</type>
<desc>
  PDF document with some properties.
</desc>
<fields>
 <field>
  <field-def>inputfile</field-def>
  <field-desc>Source PDF file</field-desc>
 </field>
 <field>
  <field-def>password</field-def>
  <field-desc>The owner password of the PDF file (if encrypted).</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_x</field-def>
  <field-desc>Overwrite rectangle x coordinate</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_y</field-def>
  <field-desc>Overwrite rectangle y coordinate</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_w</field-def>
  <field-desc>Overwrite rectangle width</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_h</field-def>
  <field-desc>Overwrite rectangle heigth</field-desc>
 </field><field>
  <field-def>overwrite_rect_color</field-def>
  <field-desc>Overwrite rectangle fill color</field-desc>
 </field>
</fields>
*/
type t_merge_input is record (
  inputfile blob,
  password varchar2(255 char),
  overwrite_rect_x number,
  overwrite_rect_y number,
  overwrite_rect_w number,
  overwrite_rect_h number,
  overwrite_rect_color t_color
  );

/**
<br/>
<h2>Merge inputs</h2>
<type>Table</type>
<desc>
  Table of Merge input records.
</desc>
<records>
 <record>
  <record-def>Input record</field-def>
  <recordd-desc>PDF document with some properties</field-desc>
 </record>
</records>
*/
type t_merge_inputs is table of t_merge_input index by pls_integer;

/**
<newpage/>
<h1>Functions</h1>
<br/>
<h2>Encryption</h2>
<p>
  A PDF document can be encrypted to protect its contents from unauthorized
  access. Encryption applies to all strings and streams in the document?s
  PDF file, but not to other object types such as integers and boolean values, which
  are used primarily to convey information about the document?s structure rather
  than its content. Leaving these values unencrypted allows random access to the
  objects within a document, while encrypting the strings and streams protects the
  document?s substantive contents.
</p>
*/

/**
<h2>Encrypt40</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 40 RC4 bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document, including extracting text and graphics
    (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>The user is allowed to add or modify text annotations,
    fill in interactive form fields, and, if "modify" is also set, create or modify interactive form fields
    (including signature fields).
  </param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>The user is allowed to print the document.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Encrypt40(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canextractcontent boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false
  ) return blob;

/**
<h2>Encrypt128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 RC4 bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Encrypt128(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>AESEncrypt128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 AES bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function AESEncrypt128(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;


/**
<h2>PublicKeyEncrypt40</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 40 RC4 bit encryption and public key certificate.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document, including extracting text and graphics
    (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>The user is allowed to add or modify text annotations,
    fill in interactive form fields, and, if "modify" is also set, create or modify interactive form fields
    (including signature fields).
  </param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>The user is allowed to print the document.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyEncrypt40(
  p_inputfile blob,
  p_certfile blob,
  p_canextractcontent boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false
  ) return blob;

/**
<h2>PublicKeyEncrypt128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 RC4 bit encryption and public key certificate.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyEncrypt128(
  p_inputfile blob,
  p_certfile blob,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>Decrypt</h2>
<type>Function</type>
<desc>
  Decrypt an encrypted (40 or 128 bits) PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 </params>
<return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
</return>
*/
function Decrypt(
  p_inputfile blob,
  p_password varchar2
  ) return blob;

/**
<h2>PublicKeyDecrypt</h2>
<type>Function</type>
<desc>
  Decrypt an encrypted (40 or 128 bits with certificate) PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the password to the certificate file</param-desc>
 </param>
 </params>
<return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyDecrypt(
  p_inputfile blob,
  p_certFile blob,
  p_password varchar2
  ) return blob;

/**
<h2>conv</h2>
<type>Function</type>
<desc>
  Util function for convert a measure to point (pt).
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_mes number</param-def>
  <param-desc>original measure</param-desc>
  <param-ul>
   <param-li>pt: point</param-li>
   <param-li>mm: millimeter</param-li>
   <param-li>cm: centimeter</param-li>
   <param-li>in: inch</param-li>
  </param-ul>
 </param>
 <param>
  <param-def>p_unit varchar2</param-def>
  <param-desc>original unit of measure</param-desc>
 </param>
</params>
<return>
 <return-def>number</return-def>
 <return-desc>measure in point</return-desc>
</return>
*/
function conv(
  p_mes number,
  p_unit varchar2   --pt,mm,cm,in
  ) return number;  --pt

/**
<h2>ExtractText</h2>
<type>Function</type>
<desc>
  Extract text content of any PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_encoding varchar2 default null</param-def>
  <param-desc>encoding of result text file (case-sensitive) see <a>http://java.sun.com/j2se/1.4.2/docs/guide/intl/encoding.doc.html</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result TEXT document</return-desc>
</return>
*/
function ExtractText(
  p_inputfile blob,
  p_encoding varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

--v2.0.7
function ExtractFormXObjectText(
  p_inputfile blob,
  p_encoding varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>Merge</h2>
<type>Function</type>
<desc>
Merge two PDF documents to a new file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile1 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_inputfile2 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password1 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_password2 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Merge(
  p_inputfile1 blob,
  p_inputfile2 blob,
  p_password1 varchar2 default null,
  p_password2 varchar2 default null
  ) return blob;

/**
<h2>MergeX</h2>
<type>Function</type>
<desc>
Merge PDF documents to a new file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfiles t_merge_inputs</param-def>
  <param-desc>source PDF files</param-desc>
 </param>
 <param>
  <param-def>p_x number default 0</param-def>
  <param-desc>X coordinate (top left) for the numbering, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def>p_y number default 0</param-def>
  <param-desc>Y coordinate (top left) for the numbering, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startNumber number default 1</param-def>
  <param-desc>Start number of the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_beginNumber number default 1</param-def>
  <param-desc>Start page index from which you want to start the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_nbAlias varchar2 default null</param-def>
  <param-desc>Page number alias, example 'nb'</param-desc>
 </param>
 <param>
  <param-def>p_cpAlias varchar2 default null</param-def>
  <param-desc>Current page number alias, example 'cp'</param-desc>
 </param>
 <param>
  <param-def>p_format varchar2 default null</param-def>
  <param-desc>Page numbering format, example 'cp / nb'</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeX(
  p_inputfiles t_merge_inputs,
  p_x number default 0, -- -1:center, -2:right
  p_y number default 0, -- -1:center, -2: bottom
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_startNumber number default 1,
  p_beginNumber number default 1,
  p_nbAlias varchar2 default null,--LL20110920
  p_cpAlias varchar2 default null, --LL20110920
  p_format varchar2 default null  --LL20110920
  ) return blob;

/**
<h2>MergeX</h2>
<type>Function</type>
<desc>
Merge PDF documents to a new file. PDF files stored in plpdf_tk_merge_inputs table.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_tr_id number</param-def>
  <param-desc>Transaction ID of the source PDF files</param-desc>
 </param>
 <param>
  <param-def>p_x number default 0</param-def>
  <param-desc>X coordinate (top left) for the numbering, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def>p_y number default 0</param-def>
  <param-desc>Y coordinate (top left) for the numbering, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startNumber number default 1</param-def>
  <param-desc>Start number of the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_beginNumber number default 1</param-def>
  <param-desc>Start page index from which you want to start the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_nbAlias varchar2 default null</param-def>
  <param-desc>Page number alias, example 'nb'</param-desc>
 </param>
 <param>
  <param-def>p_cpAlias varchar2 default null</param-def>
  <param-desc>Current page number alias, example 'cp'</param-desc>
 </param>
 <param>
  <param-def>p_format varchar2 default null</param-def>
  <param-desc>Page numbering format, example 'cp / nb'</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeX(
  p_tr_id number,
  p_x number default 0, -- -1:center, -2:right
  p_y number default 0, -- -1:center, -2: bottom
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_startNumber number default 1,
  p_beginNumber number default 1,
  p_nbAlias varchar2 default null,
  p_cpAlias varchar2 default null,
  p_format varchar2 default null
  ) return blob;

--20170605
function MergeXTOC(
  p_tr_id number,
  p_pageNum number,
  p_x number,
  p_y number,
  p_tocItemHeight number,
  p_tocItemWidth number,
  p_tocSeparator varchar2,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null
  ) return blob;

/**
<h2>MergeEncrypt128</h2>
<type>Function</type>
<desc>
  Merge two PDF files and encrypt using standard PDF 128 RC4 bit encryption.
</desc>
<version>v2.0.5</version>
<params>
 <param>
  <param-def>p_inputfile1 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_inputfile2 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password1 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_password2 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeEncrypt128(
  p_inputfile1 blob,
  p_inputfile2 blob,
  p_password1 varchar2 default null,
  p_password2 varchar2 default null,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>ReplaceUrl</h2>
<type>Function</type>
<desc>
  Replace an URL in a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_oldURI varchar2</param-def>
  <param-desc>original URL</param-desc>
 </param>
 <param>
  <param-def>p_newURI varchar2</param-def>
  <param-desc>new URL</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function ReplaceUrl(
   p_inputfile blob,
   p_oldURI varchar2,
   p_newURI varchar2,
   p_password varchar2 default null
  ) return blob;

/**
<h2>JPGStamp</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a JPG image.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_imagefile blob</param-def>
  <param-desc>JPG image</param-desc>
 </param>
 <param>
  <param-def>p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1: center, -2: right
    (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1: center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_width number default -1</param-def>
  <param-desc>Image width, if -1 then the image is displayed in its actual width
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_height number default -1</param-def>
  <param-desc>Image height, if -1 then the image is displayed in its actual height
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function JPGStamp(
  p_inputfile blob,
  p_imagefile blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password varchar2 default null,
  p_opacity number default 1
  ) return blob;

/*3 jpgstamp + merge*/
--v2.0.7
function JPGStamp3(
  p_inputfile1 blob,
  p_inputfile2 blob,
  p_inputfile3 blob,
  p_imagefile1 blob,
  p_imagefile2 blob,
  p_imagefile3 blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password1 varchar2 default null,
  p_password2 varchar2 default null,
  p_password3 varchar2 default null,
  p_opacity number default 1 
  ) return blob;

--v2.0.7
function JPGTextStamp(
  p_inputfile blob,
  --image
  p_imagefile blob,
  p_image_x number,
  p_image_y number,
  p_image_width number default -1,
  p_image_height number default -1,
  p_image_opacity number default 1,
  --text
  p_text_message varchar2,
  p_text_x number,
  p_text_y number,
  p_text_font t_14font,
  p_text_fontSize number,
  p_text_color t_color default null,
  p_text_rotation number default 0,
  p_text_opacity number default 1,
  --
  p_password varchar2 default null 
  ) return blob;

/**
<h2>JPGWaterMark</h2>
<type>Function</type>
<desc>
  Watermark content into a PDF document with a JPG image.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_imagefile blob</param-def>
  <param-desc>JPG image</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_width number default -1</param-def>
  <param-desc>Image width, if -1 then the image is displayed in its actual width
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_height number default -1</param-def>
  <param-desc>Image height, if -1 then the image is displayed in its actual height
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
 </params>
 <return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
 </return>
*/
function JPGWaterMark(
  p_inputfile blob,
  p_imagefile blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password varchar2 default null,
  p_opacity number default 1
  ) return blob;

/**
<h2>MetadataFromXML</h2>
<type>Function</type>
<desc>Set PDF metadata from an XML file.<br/>
  an example XML file:<br/>
  <i>
  &lt;?xml version="1.0" encoding="UTF-8"?&gt;<br/>
  &lt;pdf-metadata&gt;<br/>
  &lt;title&gt;PL/PDF Toolkit - User's Guide&lt;/title&gt;<br/>
  &lt;author&gt;PLPDF&lt;/author&gt;<br/>
  &lt;subject&gt;plpdf toolkit&lt;/subject&gt;<br/>
  &lt;creator&gt;PL/PDF v2.0.0&lt;/creator&gt;<br/>
  &lt;keywords&gt;Oracle PDF&lt;/keywords&gt;<br/>
  &lt;producer&gt;www.plpdf.com&lt;/producer&gt;<br/>
  &lt;createtime&gt;20080903183019&lt;/createtime&gt;<br/>
  &lt;modificationdate&gt;20080904114023&lt;/modificationdate&gt;<br/>
  &lt;/pdf-metadata&gt;<br/>
  </i>
  createtime and modificationdate format are YYYYMMDDHH24MISS
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_xmlfile blob</param-def>
  <param-desc>metadata XML file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MetadataFromXML(
  p_inputfile blob,
  p_xmlfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataFromPars</h2>
<type>Function</type>
<desc>
-
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_title varchar2 default null</param-def>
  <param-desc> The document?s title.</param-desc>
 </param>
 <param>
  <param-def> p_author varchar2 default null</param-def>
  <param-desc>The name of the person who created the document.</param-desc>
 </param>
 <param>
  <param-def> p_subject varchar2 default null</param-def>
  <param-desc>The subject of the document.</param-desc>
 </param>
 <param>
  <param-def> p_creator varchar2 default null</param-def>
  <param-desc>If the document was converted to PDF from another format, the
    name of the application (for example, Adobe FrameMaker?) that created the
    original document from which it was converted.
  </param-desc>
 </param>
 <param>
  <param-def> p_keywords varchar2 default null</param-def>
  <param-desc>Keywords associated with the document.</param-desc>
 </param>
 <param>
  <param-def> p_producer varchar2 default null</param-def>
  <param-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Acrobat Distiller) that converted it to PDF.
  </param-desc>
 </param>
 <param>
  <param-def> p_createtime date default null</param-def>
  <param-desc>The date and time the document was created, in human-readable form.</param-desc>
 </param>
 <param>
  <param-def> p_modificationdate date default null</param-def>
  <param-desc>The date and time the document was most recently modified,
   in human-readable form.
  </param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MetadataFromPars(
  p_inputfile blob,
  p_title varchar2 default null,
  p_author varchar2 default null,
  p_subject varchar2 default null,
  p_creator varchar2 default null,
  p_keywords varchar2 default null,
  p_producer varchar2 default null,
  p_createtime date default null,
  p_modificationdate date default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataToXML</h2>
<type>Function</type>
<desc>
  Extract PDF metadata into an XML file.<br/>
  An example XML file:<br/>
  <i>
  &lt;?xml version="1.0" encoding="UTF-8"?&gt;<br/>
  &lt;pdf-metadata&gt;<br/>
  &lt;title&gt;PL/PDF Toolkit - User's Guide&lt;/title&gt;<br/>
  &lt;author&gt;PLPDF&lt;/author&gt;<br/>
  &lt;subject&gt;plpdf toolkit&lt;/subject&gt;<br/>
  &lt;creator&gt;PL/PDF v2.0.0&lt;/creator&gt;<br/>
  &lt;keywords&gt;Oracle PDF&lt;/keywords&gt;<br/>
  &lt;producer&gt;www.plpdf.com&lt;/producer&gt;<br/>
  &lt;createtime&gt;20080903183019&lt;/createtime&gt;<br/>
  &lt;modificationdate&gt;20080904114023&lt;/modificationdate&gt;<br/>
  &lt;/pdf-metadata&gt;<br/>
  </i>
  createtime and modificationdate format are YYYYMMDDHH24MISS
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result XML document</return-desc>
</return>
*/
function MetadataToXML(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataToRecord</h2>
<type>Function</type>
<desc>
 Extract PDF metadata into the t_metadata record.
</desc>
<version>v2.0.0</version>
<params>
<param>
<param-def>p_inputfile blob</param-def>
<param-desc>source PDF file</param-desc>
</param>
<param>
<param-def>p_password varchar2 default null</param-def>
<param-desc>the owner password of the PDF file (if encrypted).</param-desc>
</param>
</params>
<return>
<return-def>t_metadata</return-def>
<return-desc>PDF metadata</return-desc>
</return>
*/
function MetadataToRecord(
  p_inputfile blob,
  p_password varchar2 default null
  ) return t_metadata;

/**
<h2>TextStamp</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a text.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>stamp text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
 <param-def> p_password varchar2 default null</param-def>
 <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextStamp(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_rotation number default 0,
  p_opacity number default 1
  ) return blob;

/**
<h2>TextStampTTF</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a text (TTF font type).
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>stamp text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font blob</param-def>
  <param-desc>TTF (TrueType Font) file</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc>font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
 <param-def> p_password varchar2 default null</param-def>
 <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextStampTTF(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font blob,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_rotation number default 0,
  p_opacity number default 1
  ) return blob;

/**
<h2>TextWaterMark</h2>
<type>Function</type>
<desc>
  Watermark content into a PDF document with a text.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>watermark text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc>font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color plpdf_type.t_color default null</param-def>
  <param-desc>color of text see <a>http://www.forret.com/tools/color_palette.asp</a></param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
 <param>
  <param-def>p_reencrypt boolean default false</param-def>
  <param-desc>Reencrypt document if encrypted.</param-desc>
 </param>
 </params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextWaterMark(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_rotation number default 0,
  p_opacity number default 1,
  p_reencrypt boolean default false
  ) return blob;

/**
<h2>PDFWatermark</h2>
<type>Function</type>
<desc>
  Overlay on PDF document with another one PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_overlayinputfile blob</param-def>
  <param-desc>overlay PDF file</param-desc>
 </param>
 <param>
  <param-def> p_overlaypassword varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/

function PDFWatermark(
  p_inputfile blob,
  p_overlayinputfile blob,
  p_password varchar2 default null,
  p_overlaypassword varchar2 default null
  ) return blob;

/**
<name>ExportFDF</name>
<type>Function</type>
<desc>
  Export PDF Form data as an FDF file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>FDF document</return-desc>
</return>
*/
function ExportFDF(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>ExportXFDF</name>
<type>Function</type>
<desc>
  Export PDF Form data as an XFDF file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_exportnull boolean default true</param-def>
  <param-desc>export empty fields</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>XFDF document</return-desc>
</return>
*/
function ExportXFDF(
  p_inputfile blob,
  p_password varchar2 default null,
  p_exportnull boolean default true
  ) return blob;

/**
<name>ImportFDF</name>
<type>Function</type>
<desc>
  Import an FDF file into the PDF Form's fields.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_fdffile blob</param-def>
  <param-desc>FDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>FDF document</return-desc>
</return>
*/
function ImportFDF(
  p_inputfile blob,
  p_fdffile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>ImportXFDF</name>
<type>Function</type>
<desc>
  Import an XFDF file into the PDF Form's fields.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_xfdffile blob</param-def>
  <param-desc>XFDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_needapp boolean default true</param-def>
  <param-desc>Set NeedAppearances option in PDF source.
	When NeedAppearances is true then force compliant PDF readers to render the fields.
	If false then toolkit automatically generates the appearance streams for all form fields.
  </param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>XFDF document</return-desc>
</return>
*/
function ImportXFDF(
  p_inputfile blob,
  p_xfdffile blob,
  p_password varchar2 default null,
  p_needapp boolean default true
  ) return blob;

/**
<h2>ExtractPages</h2>
<type>Function</type>
<desc>
  Extract pages of any PDF document into a new PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function ExtractPages(
  p_inputfile blob,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>GetNumberOfPages</h2>
<type>Function</type>
<desc>
  Get number of pages of any PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>number</return-def>
 <return-desc>number of pages</return-desc>
</return>
*/
function GetNumberOfPages(
  p_inputfile blob,
  p_password varchar2 default null
  ) return number;

/**
<h2>JPGCompress</h2>
<type>Function</type>
<desc>
  Sets the compression quality to a value between 0  and 1 of the JPG images in a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_compress number</param-def>
  <param-desc>compression quality to a value between 0  and 1</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function JPGCompress(
   p_inputfile blob,
   p_compress number,
   p_password varchar2 default null
  ) return blob;

/**
<h2>DigSign</h2>
<type>Function</type>
<desc>
  Digital sign a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_keystore blob</param-def>
  <param-desc>keystore file</param-desc>
 </param>
 <param>
  <param-def>p_certAlias varchar2 default null</param-def>
  <param-desc>certificate alias in keystore file, null means first the first alias</param-desc>
 </param>
 <param>
  <param-def>p_keystorePassword varchar2 default null</param-def>
  <param-desc>password of keystore</param-desc>
 </param>
 <param>
  <param-def>p_privkeyPassword varchar2 default null</param-def>
  <param-desc>password of private key</param-desc>
 </param>
 <param>
   <param-def>p_Name varchar2 default null</param-def>
   <param-desc>The name of the person or authority signing the document.</param-desc>
  </param>
  <param>
   <param-def>p_Location varchar2 default null</param-def>
   <param-desc>The CPU host name or physical location of the signing.</param-desc>
  </param>
  <param>
   <param-def>p_Reason varchar2 default null</param-def>
   <param-desc>The reason for the signing, such as (I agree?).</param-desc>
  </param>
  <param>
   <param-def>p_ContactInfo varchar2 default null</param-def>
   <param-desc>Information provided by the signer to allow a recipient to contact the signer to verify the signature; for example, a phone number.</param-desc>
  </param>
  <param>
   <param-def>p_page number default 0</param-def>
   <param-desc>page number of digital signature's postion </param-desc>
  </param>
  <param>
   <param-def>p_x number default 0</param-def>
   <param-desc>X coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_y number default 0</param-def>
   <param-desc>Y coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_w number default 0</param-def>
   <param-desc>The width of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_h number default 0</param-def>
   <param-desc>The height of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_access_perms</param-def>
   <param-desc>The access permissions granted for this document. Defined values are:</param-desc>
   <param-ul>
     <param-li>1: No changes to the document are permitted; any change to the document invalidates the signature.</param-li>
     <param-li>2: Permitted changes are filling in forms, instantiating page templates, and signing; other changes invalidate the signature.</param-li>
     <param-li>3: Permitted changes are those allowed by 2, as well as annotation creation, deletion, and modification; other changes invalidate the signature.</param-li>
    </param-ul>
  </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function DigSign(
   p_inputfile blob,
   p_keystore blob,
   p_certAlias varchar2 default null,
   p_keystorePassword varchar2 default null,
   p_privkeyPassword varchar2 default null,
   p_Name varchar2 default null,
   p_Location varchar2 default null,
   p_Reason varchar2 default null,
   p_ContactInfo varchar2 default null,
   p_page number default 0,
   p_x number default 0,
   p_y number default 0,
   p_width number default 0,
   p_height number default 0,
   p_accessPerms number default 1,
   p_password varchar2  default null
  ) return blob;

/**
<h2>DigSignEncrypt</h2>
<type>Function</type>
<desc>
  Digital sign and encrypt a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_keystore blob</param-def>
  <param-desc>keystore file</param-desc>
 </param>
 <param>
  <param-def>p_certAlias varchar2 default null</param-def>
  <param-desc>certificate alias in keystore file, null means first the first alias</param-desc>
 </param>
 <param>
  <param-def>p_keystorePassword varchar2 default null</param-def>
  <param-desc>password of keystore</param-desc>
 </param>
 <param>
  <param-def>p_privkeyPassword varchar2 default null</param-def>
  <param-desc>password of private key</param-desc>
 </param>
 <param>
   <param-def>p_Name varchar2 default null</param-def>
   <param-desc>The name of the person or authority signing the document.</param-desc>
  </param>
  <param>
   <param-def>p_Location varchar2 default null</param-def>
   <param-desc>The CPU host name or physical location of the signing.</param-desc>
  </param>
  <param>
   <param-def>p_Reason varchar2 default null</param-def>
   <param-desc>The reason for the signing, such as (I agree?).</param-desc>
  </param>
  <param>
   <param-def>p_ContactInfo varchar2 default null</param-def>
   <param-desc>Information provided by the signer to allow a recipient to contact the signer to verify the signature; for example, a phone number.</param-desc>
  </param>
  <param>
   <param-def>p_page number default 0</param-def>
   <param-desc>page number of digital signature's postion </param-desc>
  </param>
  <param>
   <param-def>p_x number default 0</param-def>
   <param-desc>X coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_y number default 0</param-def>
   <param-desc>Y coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_w number default 0</param-def>
   <param-desc>The width of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_h number default 0</param-def>
   <param-desc>The height of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_access_perms</param-def>
   <param-desc>The access permissions granted for this document. Defined values are:</param-desc>
   <param-ul>
     <param-li>1: No changes to the document are permitted; any change to the document invalidates the signature.</param-li>
     <param-li>2: Permitted changes are filling in forms, instantiating page templates, and signing; other changes invalidate the signature.</param-li>
     <param-li>3: Permitted changes are those allowed by 2, as well as annotation creation, deletion, and modification; other changes invalidate the signature.</param-li>
    </param-ul>
  </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
 <param>
  <param-def>p_algorithm varchar2 default 'RC4'</param-def>
  <param-desc>The encryption algorithm, possible values are RC4 and AES</param-desc>
 </param>
 <param>
  <param-def>p_keylength number default 40</param-def>
  <param-desc>The encryption key length in bit, possible values are 40 and 128</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function DigSignEncrypt(
   p_inputfile blob,
   p_keystore blob,
   p_certAlias varchar2 default null,
   p_keystorePassword varchar2 default null,
   p_privkeyPassword varchar2 default null,
   p_name varchar2 default null,
   p_location varchar2 default null,
   p_reason varchar2 default null,
   p_contactInfo varchar2 default null,
   p_page number default 0,
   p_x number default 0,
   p_y number default 0,
   p_width number default 0,
   p_height number default 0,
   p_accessPerms number default 1,
   p_password varchar2 default null,
   p_opassword varchar2,
   p_upassword varchar2 default null,
   p_canassemble boolean default false,
   p_canextractcontent boolean default false,
   p_canextractforaccessibility boolean default false,
   p_canfillinform boolean default false,
   p_canmodify boolean default false,
   p_canmodifyannotations boolean default false,
   p_canprint boolean default false,
   p_canmodifyprintresolution boolean default false, --v1.8.0
   p_algorithm varchar2 default 'RC4',
   p_keylength number default 40
  ) return blob;

/**
<h2>Rebuild</h2>
<type>Function</type>
<desc>
  Rebuild any PDF document into a new PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Rebuild(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>Get_Version</name>
<type>Function</type>
<desc>
  Get version number of the toolkit.
</desc>
<version>v2.0.0</version>
<return>
 <return-def>varchar2</return-def>
 <return-desc>version number</return-desc>
</return>
*/
function get_Version return varchar2;

/**
<name>Get_VersionDate</name>
<type>Function</type>
<desc>
  Get release date of the toolkit.
</desc>
<version>v2.0.0</version>
<return>
 <return-def>varchar2</return-def>
 <return-desc>release date</return-desc>
</return>
*/
function get_VersionDate return varchar2;


/**
<h2>setFieldsReadonly</h2>
<type>Function</type>
<desc>
  Set the PDF form fields to read-only.
</desc>
<version>v2.0.1</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_raise_noform boolean default null</param-def>
  <param-desc>Raise no form error or not</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function setFieldsReadonly(
  p_inputfile blob,
  p_password varchar2 default null,
  p_raise_noform boolean default null
  ) return blob;


/**
<h2>getPDFACompliant</h2>
<type>Function</type>
<desc>
  Get the PDF/A Compliant information.
</desc>
<version>v2.0.1</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>The Compliant info</return-def>
 <return-desc>Format is part + conf, example 1B</return-desc>
</return>
*/
function getPDFACompliant(
  p_inputfile blob,
  p_password varchar2 default null
  ) return varchar2;


/**
<h2>verifySignature</h2>
<type>Function</type>
<desc>
  verify Signature in the PDF file and the resultg is an XML
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result XML document</return-desc>
</return>
*/
function verifySignature(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;
-- end of package

-------------------------------------------------------
/**
 <newpage/>
 <h1>Version History</h1>
 <br/>
 */
-------------------------------------------------------

/**
 <h2>18-DEC-2013, v2.0.0</h2>
 <p>- new function: get_Version</p>
 <p>- new function: get_VersionDate</p>
 <p>- ImportXFDF: new parameter: p_needapp</p>
 <p>- TextWaterMark: new parameter: p_reencrypt</p>
*/

end;
/

CREATE OR REPLACE PACKAGE BODY plpdf_toolkit wrapped 
a000000
aa
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
b
11349 8ab6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/
